@@ -1,6 +1,8 @@
 #include "evas_common.h"
 #include "evas_private.h"
 
+static void _evas_layer_free(Evas_Layer *lay);
+
 void
 evas_object_inject(Evas_Object *obj, Evas *e)
 {
@@ -31,7 +33,7 @@ evas_object_release(Evas_Object *obj, int clean_layer)
 	if (obj->layer->usage <= 0)
 	  {
 	     evas_layer_del(obj->layer);
-	     evas_layer_free(obj->layer);
+	     _evas_layer_free(obj->layer);
 	  }
      }
    obj->layer = NULL;
@@ -49,6 +51,12 @@ evas_layer_new(Evas *e)
    return lay;
 }
 
+static void
+_evas_layer_free(Evas_Layer *lay)
+{
+   free(lay);
+}
+
 void
 evas_layer_pre_free(Evas_Layer *lay)
 {
@@ -62,7 +70,7 @@ evas_layer_pre_free(Evas_Layer *lay)
 }
 
 void
-evas_layer_free(Evas_Layer *lay)
+evas_layer_free_objects(Evas_Layer *lay)
 {
    while (lay->objects)
      {
@@ -71,7 +79,19 @@ evas_layer_free(Evas_Layer *lay)
 	obj = (Evas_Object *)lay->objects;
 	evas_object_free(obj, 0);
      }
-   free(lay);
+}
+
+void
+evas_layer_clean(Evas *e)
+{
+   Evas_Layer *tmp;
+
+   while (e->layers)
+     {
+	tmp = e->layers;
+	evas_layer_del(tmp);
+	_evas_layer_free(tmp);
+     }
 }
 
 Evas_Layer *
@@ -122,6 +142,9 @@ evas_layer_del(Evas_Layer *lay)
 
 /**
  * Sets the layer of the evas that the given object will be part of.
+ *
+ * It is not possible to change the layer of a smart object's child.
+ *
  * @param   obj The given evas object.
  * @param   l   The number of the layer to place the object on.
  */
@@ -170,6 +193,11 @@ evas_object_layer_set(Evas_Object *obj, short l)
 
 /**
  * Retrieves the layer of the evas that the given object is part of.
+ *
+ * Be carefull, it doesn't make sense to change the layer of smart object's
+ * child. So the returned value could be wrong in some case. Don't rely on
+ * it's accuracy.
+ *
  * @param   obj The given evas object.
  * @return  Number of the layer.
  */
