@@ -63,6 +63,7 @@ static const Evas_Object_Func object_func =
      NULL,
      NULL,
      NULL,
+     NULL,
      NULL
 };
 
@@ -140,6 +141,7 @@ evas_object_gradient2_linear_fill_set(Evas_Object *obj, float x0, float y0, floa
    evas_object_change(obj);
 }
 
+/*FIXME: To be documented*/
 EAPI void
 evas_object_gradient2_linear_fill_get(const Evas_Object *obj, float *x0, float *y0, float *x1, float *y1)
 {
@@ -240,7 +242,7 @@ evas_object_gradient2_linear_free(Evas_Object *obj)
       obj->layer->evas->engine.func->gradient2_linear_free(obj->layer->evas->engine.data.output,
 							  o->engine_data);
    free(o);
-   obj->object_data = NULL; 
+   obj->object_data = NULL;
 }
 
 
@@ -333,7 +335,7 @@ evas_object_gradient2_linear_render_pre(Evas_Object *obj)
 	  }
 	og->cur.gradient_opaque = obj->layer->evas->engine.func->gradient2_linear_is_opaque(obj->layer->evas->engine.data.output,
 										   obj->layer->evas->engine.data.context,
-				  						   o->engine_data,
+										   o->engine_data,
 										   obj->cur.cache.clip.x, obj->cur.cache.clip.y,
 										   obj->cur.cache.clip.w, obj->cur.cache.clip.h);
 
@@ -350,6 +352,12 @@ evas_object_gradient2_linear_render_pre(Evas_Object *obj)
 	evas_object_render_pre_visible_change(&obj->layer->evas->clip_changes, obj, is_v, was_v);
 	goto done;
      }
+   if ((obj->cur.map != obj->prev.map) ||
+       (obj->cur.usemap != obj->prev.usemap))
+     {
+	evas_object_render_pre_prev_cur_add(&obj->layer->evas->clip_changes, obj);
+        goto done;
+     }
    /* its not visible - we accounted for it appearing or not so just abort */
    if (!is_v) goto done;
    /* clipper changed this is in addition to anything else for obj */
@@ -372,7 +380,7 @@ evas_object_gradient2_linear_render_pre(Evas_Object *obj)
    /* it obviously didn't change - add a NO obscure - this "unupdates"  this */
    /* area so if there were updates for it they get wiped. don't do it if we */
    /* arent fully opaque and we are visible */
-   
+
    if (evas_object_is_visible(obj) &&
        evas_object_is_opaque(obj))
      obj->layer->evas->engine.func->output_redraws_rect_del(obj->layer->evas->engine.data.output,
@@ -380,7 +388,7 @@ evas_object_gradient2_linear_render_pre(Evas_Object *obj)
 							    obj->cur.cache.clip.y,
 							    obj->cur.cache.clip.w,
 							    obj->cur.cache.clip.h);
-   
+
    done:
    evas_object_render_pre_effect_updates(&obj->layer->evas->clip_changes, obj, is_v, was_v);
 }
@@ -444,6 +452,7 @@ evas_object_gradient2_linear_is_opaque(Evas_Object *obj)
 
    /* this returns 1 if the internal object data implies that the object is */
    /* currently fully opaque over the entire region it occupies */
+   if ((obj->cur.map) && (obj->cur.usemap)) return 0;
    o = (Evas_Object_Gradient2_Linear *)(obj->object_data);
    if (!o->engine_data) return 0;
    og = (Evas_Object_Gradient2 *)(o);
