@@ -63,6 +63,7 @@ static const Evas_Object_Func rg_object_func =
      NULL,
      NULL,
      NULL,
+     NULL,
      NULL
 };
 
@@ -239,7 +240,7 @@ evas_object_gradient2_radial_free(Evas_Object *obj)
       obj->layer->evas->engine.func->gradient2_radial_free(obj->layer->evas->engine.data.output,
 							  o->engine_data);
    free(o);
-   obj->object_data = NULL; 
+   obj->object_data = NULL;
 }
 
 
@@ -332,7 +333,7 @@ evas_object_gradient2_radial_render_pre(Evas_Object *obj)
 	  }
 	og->cur.gradient_opaque = obj->layer->evas->engine.func->gradient2_radial_is_opaque(obj->layer->evas->engine.data.output,
 										   obj->layer->evas->engine.data.context,
-				  						   o->engine_data,
+										   o->engine_data,
 										   obj->cur.cache.clip.x, obj->cur.cache.clip.y,
 										   obj->cur.cache.clip.w, obj->cur.cache.clip.h);
 
@@ -348,6 +349,12 @@ evas_object_gradient2_radial_render_pre(Evas_Object *obj)
 	evas_object_render_pre_visible_change(&obj->layer->evas->clip_changes, obj, is_v, was_v);
 	goto done;
      }
+   if ((obj->cur.map != obj->prev.map) ||
+       (obj->cur.usemap != obj->prev.usemap))
+     {
+	evas_object_render_pre_prev_cur_add(&obj->layer->evas->clip_changes, obj);
+        goto done;
+     }
    /* its not visible - we accounted for it appearing or not so just abort */
    if (!is_v) goto done;
    /* clipper changed this is in addition to anything else for obj */
@@ -370,7 +377,7 @@ evas_object_gradient2_radial_render_pre(Evas_Object *obj)
    /* it obviously didn't change - add a NO obscure - this "unupdates"  this */
    /* area so if there were updates for it they get wiped. don't do it if we */
    /* arent fully opaque and we are visible */
-   
+
    if (evas_object_is_visible(obj) &&
        evas_object_is_opaque(obj))
      obj->layer->evas->engine.func->output_redraws_rect_del(obj->layer->evas->engine.data.output,
@@ -378,7 +385,7 @@ evas_object_gradient2_radial_render_pre(Evas_Object *obj)
 							    obj->cur.cache.clip.y,
 							    obj->cur.cache.clip.w,
 							    obj->cur.cache.clip.h);
-   
+
    done:
    evas_object_render_pre_effect_updates(&obj->layer->evas->clip_changes, obj, is_v, was_v);
 }
@@ -442,6 +449,7 @@ evas_object_gradient2_radial_is_opaque(Evas_Object *obj)
 
    /* this returns 1 if the internal object data implies that the object is */
    /* currently fully opaque over the entire region it occupies */
+   if ((obj->cur.map) && (obj->cur.usemap)) return 0;
    o = (Evas_Object_Gradient2_Radial *)(obj->object_data);
    if (!o->engine_data) return 0;
    og = (Evas_Object_Gradient2 *)(o);
