@@ -65,6 +65,7 @@ static const Evas_Object_Func object_func =
      evas_object_line_coords_recalc,
      NULL,
      NULL,
+     NULL,
      NULL
 };
 
@@ -155,8 +156,8 @@ evas_object_line_xy_set(Evas_Object *obj, Evas_Coord x1, Evas_Coord y1, Evas_Coo
      }
    obj->cur.geometry.x = min_x;
    obj->cur.geometry.y = min_y;
-   obj->cur.geometry.w = max_x - min_x + 2.0;
-   obj->cur.geometry.h = max_y - min_y + 2.0;
+   obj->cur.geometry.w = max_x - min_x + 2;
+   obj->cur.geometry.h = max_y - min_y + 2;
 ////   obj->cur.cache.geometry.validity = 0;
    o->cur.x1 = x1 - min_x;
    o->cur.y1 = y1 - min_y;
@@ -203,18 +204,18 @@ evas_object_line_xy_get(const Evas_Object *obj, Evas_Coord *x1, Evas_Coord *y1,
    Evas_Object_Line *o;
 
    MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
-   if (x1) *x1 = 0.0;
-   if (y1) *y1 = 0.0;
-   if (x2) *x2 = 0.0;
-   if (y2) *y2 = 0.0;
+   if (x1) *x1 = 0;
+   if (y1) *y1 = 0;
+   if (x2) *x2 = 0;
+   if (y2) *y2 = 0;
    return;
    MAGIC_CHECK_END();
    o = (Evas_Object_Line *)(obj->object_data);
    MAGIC_CHECK(o, Evas_Object_Line, MAGIC_OBJ_LINE);
-   if (x1) *x1 = 0.0;
-   if (y1) *y1 = 0.0;
-   if (x2) *x2 = 0.0;
-   if (y2) *y2 = 0.0;
+   if (x1) *x1 = 0;
+   if (y1) *y1 = 0;
+   if (x2) *x2 = 0;
+   if (y2) *y2 = 0;
    return;
    MAGIC_CHECK_END();
    if (x1) *x1 = obj->cur.geometry.x + o->cur.x1;
@@ -260,10 +261,10 @@ evas_object_line_new(void)
    /* alloc obj private data */
    o = calloc(1, sizeof(Evas_Object_Line));
    o->magic = MAGIC_OBJ_LINE;
-   o->cur.x1 = 0.0;
-   o->cur.y1 = 0.0;
-   o->cur.x2 = 31.0;
-   o->cur.y2 = 31.0;
+   o->cur.x1 = 0;
+   o->cur.y1 = 0;
+   o->cur.x2 = 31;
+   o->cur.y2 = 31;
    o->prev = o->cur;
    return o;
 }
@@ -342,6 +343,12 @@ evas_object_line_render_pre(Evas_Object *obj)
 	evas_object_render_pre_visible_change(&obj->layer->evas->clip_changes, obj, is_v, was_v);
 	goto done;
      }
+   if ((obj->cur.map != obj->prev.map) ||
+       (obj->cur.usemap != obj->prev.usemap))
+     {
+	evas_object_render_pre_prev_cur_add(&obj->layer->evas->clip_changes, obj);
+        goto done;
+     }
    /* it's not visible - we accounted for it appearing or not so just abort */
    if (!is_v) goto done;
    /* clipper changed this is in addition to anything else for obj */
