@@ -3,7 +3,6 @@
  */
 
 #include "evas_common.h"
-
 #if defined BUILD_MMX || defined BUILD_SSE
 #include "evas_mmx.h"
 #endif
@@ -222,7 +221,7 @@ evas_common_cpu_can_do(int *mmx, int *sse, int *sse2)
 	if (cpu_feature_mask & CPU_FEATURE_MMX2) do_sse = 1;
 	if (cpu_feature_mask & CPU_FEATURE_SSE) do_sse = 1;
      }
-//   printf("%i %i %i\n", do_mmx, do_sse, do_sse2);
+//   INF("%i %i %i", do_mmx, do_sse, do_sse2);
    *mmx = do_mmx;
    *sse = do_sse;
    *sse2 = do_sse2;
@@ -245,30 +244,3 @@ evas_common_cpu_end_opt(void)
 {
 }
 #endif
-
-EAPI int
-evas_common_cpu_count(void)
-{
-#ifdef BUILD_PTHREAD
-   cpu_set_t cpu;
-   int i;
-   static int cpus = 0;
-
-   if (cpus != 0) return cpus;
-
-   CPU_ZERO(&cpu);
-   if (sched_getaffinity(0, sizeof(cpu), &cpu) != 0)
-     {
-	printf("[Evas] could not get cpu affinity: %s\n", strerror(errno));
-	return 1;
-     }
-   for (i = 0; i < TH_MAX; i++)
-     {
-	if (CPU_ISSET(i, &cpu)) cpus = i + 1;
-	else break;
-     }
-   return cpus;
-#else
-   return 1;
-#endif
-}
