@@ -46,7 +46,7 @@ EAPI RGBA_Font        *evas_common_font_add                  (RGBA_Font *fn, con
 EAPI RGBA_Font        *evas_common_font_memory_add           (RGBA_Font *fn, const char *name, int size, const void *data, int data_size);
 EAPI void              evas_common_font_free                 (RGBA_Font *fn);
 EAPI void              evas_common_font_hinting_set          (RGBA_Font *fn, Font_Hint_Flags hinting);
-EAPI Evas_Bool         evas_common_hinting_available         (Font_Hint_Flags hinting);
+EAPI Eina_Bool         evas_common_hinting_available         (Font_Hint_Flags hinting);
 EAPI RGBA_Font        *evas_common_font_memory_hinting_load  (const char *name, int size, const void *data, int data_size, Font_Hint_Flags hinting);
 EAPI RGBA_Font        *evas_common_font_hinting_load         (const char *name, int size, Font_Hint_Flags hinting);
 EAPI RGBA_Font        *evas_common_font_hinting_add          (RGBA_Font *fn, const char *name, int size, Font_Hint_Flags hinting);
@@ -68,4 +68,7 @@ EAPI int               evas_common_font_query_char_coords    (RGBA_Font *fn, con
 EAPI int               evas_common_font_query_text_at_pos    (RGBA_Font *fn, const char *text, int x, int y, int *cx, int *cy, int *cw, int *ch);
 EAPI int               evas_common_font_query_last_up_to_pos (RGBA_Font *fn, const char *text, int x, int y);
 
+void evas_common_font_load_init(void);
+void evas_common_font_load_shutdown(void);
+
 #endif /* _EVAS_FONT_H */
