@@ -3,7 +3,7 @@
  */
 
 #include "evas_common.h"
-
+#include "evas_private.h"
 FT_Library      evas_ft_lib = 0;
 static int      initialised = 0;
 
@@ -20,6 +20,7 @@ evas_common_font_init(void)
 	initialised--;
 	return;
      }
+   evas_common_font_load_init();
 }
 
 EAPI void
@@ -30,6 +31,7 @@ evas_common_font_shutdown(void)
    initialised--;
    if (initialised != 0) return;
 
+   evas_common_font_load_shutdown();
    evas_common_font_cache_set(0);
    evas_common_font_flush();
 
@@ -134,9 +136,11 @@ evas_common_font_utf8_get_next(const unsigned char *buf, int *iindex)
    int index = *iindex, len, r;
    unsigned char d, d2, d3, d4;
 
-   d = buf[index++];
-   if (!d)
+   /* if this char is the null terminator, exit */
+   if (!buf[index])
      return 0;
+     
+   d = buf[index++];
 
    while (buf[index] && ((buf[index] & 0xc0) == 0x80))
      index++;
@@ -191,52 +195,22 @@ evas_common_font_utf8_get_prev(const unsigned char *buf, int *iindex)
     *
     * Returns 0 to indicate there is no prev char
     */
-   int index = *iindex, len, r;
-   unsigned char d, d2, d3, d4;
 
-   if (index <= 0)
+   int r;
+   int index = *iindex;
+   /* although when index == 0 there's no previous char, we still want to get
+    * the current char */
+   if (index < 0) 
      return 0;
-   d = buf[index--];
 
+   /* First obtain the codepoint at iindex */
+   r = evas_common_font_utf8_get_next(buf, &index);
+
+   /* Next advance iindex to previous codepoint */
+   index = *iindex;
+   index--;
    while ((index > 0) && ((buf[index] & 0xc0) == 0x80))
      index--;
-   len = *iindex - index;
-
-   if (len == 1)
-      r = d;
-   else if (len == 2)
-     {
-	/* 2 bytes */
-        d2 = buf[index + 1];
-	r = d & 0x1f; /* copy lower 5 */
-	r <<= 6;
-	r |= (d2 & 0x3f); /* copy lower 6 */
-     }
-   else if (len == 3)
-     {
-	/* 3 bytes */
-        d2 = buf[index + 1];
-        d3 = buf[index + 2];
-	r = d & 0x0f; /* copy lower 4 */
-	r <<= 6;
-	r |= (d2 & 0x3f);
-	r <<= 6;
-	r |= (d3 & 0x3f);
-     }
-   else
-     {
-	/* 4 bytes */
-        d2 = buf[index + 1];
-        d3 = buf[index + 2];
-        d4 = buf[index + 3];
-	r = d & 0x0f; /* copy lower 4 */
-	r <<= 6;
-	r |= (d2 & 0x3f);
-	r <<= 6;
-	r |= (d3 & 0x3f);
-	r <<= 6;
-	r |= (d4 & 0x3f);
-     }
 
    *iindex = index;
    return r;
