@@ -6,14 +6,12 @@
 #include "evas_private.h"
 #include "evas_cs.h"
 
-extern Eina_List *evas_modules;
-
 struct ext_loader_s {
    const char*	extention;
    const char*	loader;
 };
 
-static struct ext_loader_s	loaders[] = {
+static struct ext_loader_s	const loaders[] = {
    { "png", "png" },
    { "jpg", "jpeg" },
    { "jpeg", "jpeg" },
@@ -34,12 +32,34 @@ static struct ext_loader_s	loaders[] = {
    { "pnm", "pmaps" }
 };
 
+static const char *loaders_name[] = {
+  "png", "jpeg", "eet", "xpm", "tiff", "gif", "svg", "pmaps", "edb"
+};
+
+static Eina_Bool
+_evas_image_foreach_loader(const Eina_Hash *hash __UNUSED__, const char *key __UNUSED__, Evas_Module *em, Image_Entry *ie)
+{
+   Evas_Image_Load_Func *evas_image_load_func = NULL;
+
+   if (!evas_module_load(em)) return EINA_TRUE;
+   evas_image_load_func = em->functions;
+   evas_module_use(em);
+   if (evas_image_load_func && evas_image_load_func->file_head(ie, ie->file, ie->key))
+     {
+	ie->info.module = (void *)em;
+	ie->info.loader = (void *)evas_image_load_func;
+	evas_module_ref((Evas_Module *)ie->info.module);
+	return EINA_FALSE;
+     }
+
+   return EINA_TRUE;
+}
+
 EAPI int
 evas_common_load_rgba_image_module_from_file(Image_Entry *ie)
 {
    Evas_Image_Load_Func *evas_image_load_func = NULL;
    const char           *loader = NULL;
-   Eina_List            *l;
    Evas_Module          *em;
    char                 *dot;
    int                   i;
@@ -59,7 +79,7 @@ evas_common_load_rgba_image_module_from_file(Image_Entry *ie)
      {
 	for (i = 0, ++dot; i < (sizeof (loaders) / sizeof (struct ext_loader_s)); ++i)
 	  {
-	     if (!strcasecmp (dot, loaders[i].extention))
+	     if (!strcasecmp(dot, loaders[i].extention))
 	       {
 		  loader = loaders[i].loader;
 		  break;
@@ -78,23 +98,29 @@ evas_common_load_rgba_image_module_from_file(Image_Entry *ie)
 		  evas_image_load_func = em->functions;
 		  if (evas_image_load_func->file_head(ie, ie->file, ie->key))
 		    goto ok;
+		  evas_module_unload(em);
 	       }
 	  }
      }
 
-   EINA_LIST_FOREACH(evas_modules, l, em)
+   evas_module_foreach_image_loader(_evas_image_foreach_loader, ie);
+   if (ie->info.module) return 0;
+
+   /* This is our last chance, try all known image loader. */
+   /* FIXME: We could use eina recursive module search ability. */
+   for (i = 0; i < sizeof (loaders_name) / sizeof (char *); i++)
      {
-	if (em->type != EVAS_MODULE_TYPE_IMAGE_LOADER) continue;
-	if (!evas_module_load(em)) continue;
-        evas_image_load_func = em->functions;
-	evas_module_use(em);
-	if (evas_image_load_func && evas_image_load_func->file_head(ie, ie->file, ie->key))
+	em = evas_module_find_type(EVAS_MODULE_TYPE_IMAGE_LOADER, loaders_name[i]);
+	if (em)
 	  {
-	     if (evas_modules != l)
+	     if (evas_module_load(em))
 	       {
-		  evas_modules = eina_list_promote_list(evas_modules, l);
+		  evas_module_use(em);
+		  evas_image_load_func = em->functions;
+		  if (evas_image_load_func->file_head(ie, ie->file, ie->key))
+		    goto ok;
+		  evas_module_unload(em);
 	       }
-	     goto ok;
 	  }
      }
 
@@ -139,7 +165,9 @@ evas_common_load_rgba_image_data_from_file(Image_Entry *ie)
    evas_image_load_func = ie->info.loader;
    evas_module_use((Evas_Module*) ie->info.module);
    if (!evas_image_load_func->file_data(ie, ie->file, ie->key))
-     return -1;
+     {
+        return -1;
+     }
 
 //   evas_module_unref((Evas_Module*) ie->info.module);
 //   ie->info.module = NULL;
