@@ -53,7 +53,7 @@ static int               _evas_common_rgba_image_dirty(Image_Entry* dst, const I
 static void
 _evas_common_rgba_image_debug(const char* context, Image_Entry *eim)
 {
-   fprintf(stderr, "%p = [%s] {%s,%s} %i [%i|%i]\n", eim, context, eim->file, eim->key, eim->references, eim->w, eim->h);
+  DBG("%p = [%s] {%s,%s} %i [%i|%i]", eim, context, eim->file, eim->key, eim->references, eim->w, eim->h);
 }
 
 static const Evas_Cache_Image_Func      _evas_common_image_func =
@@ -83,7 +83,7 @@ evas_common_image_init(void)
    if (!eci)
      eci = evas_cache_image_init(&_evas_common_image_func);
    reference++;
-////   printf("REF++=%i\n", reference);
+////   ERR("REF++=%i", reference);
 
 #ifdef BUILD_LOADER_EET
    eet_init();
@@ -175,7 +175,7 @@ evas_common_rgba_image_unload(Image_Entry *ie)
    if (!ie->flags.loaded) return;
    if ((!ie->info.module) && (!ie->data1)) return;
    if (!ie->file) return;
-   
+
    ie->flags.loaded = 0;
 
    if ((im->cs.data) && (im->image.data))
