@@ -48,23 +48,24 @@ typedef struct _Evas_Intercept_Func_Color   Evas_Intercept_Func_Color;
 typedef struct _Evas_Key_Grab               Evas_Key_Grab;
 typedef struct _Evas_Callbacks              Evas_Callbacks;
 typedef struct _Evas_Format                 Evas_Format;
+typedef struct _Evas_Map_Point              Evas_Map_Point;
 
-#define MAGIC_EVAS          0x70777770
-#define MAGIC_OBJ           0x71777770
-#define MAGIC_OBJ_RECTANGLE 0x71777771
-#define MAGIC_OBJ_LINE      0x71777772
-#define MAGIC_OBJ_GRADIENT  0x71777773
-#define MAGIC_OBJ_POLYGON   0x71777774
-#define MAGIC_OBJ_IMAGE     0x71777775
-#define MAGIC_OBJ_TEXT      0x71777776
-#define MAGIC_OBJ_SMART     0x71777777
-#define MAGIC_OBJ_TEXTBLOCK 0x71777778
-#define MAGIC_SMART         0x72777770
+#define MAGIC_EVAS                 0x70777770
+#define MAGIC_OBJ                  0x71777770
+#define MAGIC_OBJ_RECTANGLE        0x71777771
+#define MAGIC_OBJ_LINE             0x71777772
+#define MAGIC_OBJ_GRADIENT         0x71777773
+#define MAGIC_OBJ_POLYGON          0x71777774
+#define MAGIC_OBJ_IMAGE            0x71777775
+#define MAGIC_OBJ_TEXT             0x71777776
+#define MAGIC_OBJ_SMART            0x71777777
+#define MAGIC_OBJ_TEXTBLOCK        0x71777778
+#define MAGIC_SMART                0x72777770
 #define MAGIC_OBJ_GRADIENT_LINEAR  0x72777771
 #define MAGIC_OBJ_GRADIENT_RADIAL  0x72777772
-#define MAGIC_OBJ_SHAPE  0x72777773
-#define MAGIC_OBJ_CONTAINER  0x72777774
-#define MAGIC_OBJ_CUSTOM  0x72777775
+#define MAGIC_OBJ_SHAPE            0x72777773
+#define MAGIC_OBJ_CONTAINER        0x72777774
+#define MAGIC_OBJ_CUSTOM           0x72777775
 
 #ifdef MAGIC_DEBUG
 # define MAGIC_CHECK_FAILED(o, t, m) \
@@ -287,8 +288,8 @@ struct _Evas
    Eina_Array     delete_objects;
    Eina_Array     active_objects;
    Eina_Array     restack_objects;
-   Eina_Array	  render_objects;
-   Eina_Array	  pending_objects;
+   Eina_Array     render_objects;
+   Eina_Array     pending_objects;
    Eina_Array     obscuring_objects;
    Eina_Array     temporary_objects;
    Eina_Array     calculate_objects;
@@ -357,6 +358,25 @@ struct _Evas_Size_Hints
    Evas_Border padding;
 };
 
+struct _Evas_Map_Point
+{
+   Evas_Coord x, y, z;
+   double u, v;
+   unsigned char r, g, b, a;
+};
+
+struct _Evas_Map
+{
+   int count; // num of points
+   Evas_Coord_Rectangle normal_geometry; // bounding box of map geom actually
+   void *surface; // surface holding map if needed
+   int surface_w, surface_h; // current surface w & h alloc
+   Evas_Coord mx, my; // mouse x, y after conversion to map space
+   Eina_Bool alpha : 1;
+   Eina_Bool smooth : 1;
+   Evas_Map_Point points[]; // actual points
+};
+
 struct _Evas_Object
 {
    EINA_INLIST;
@@ -382,12 +402,14 @@ struct _Evas_Object
 	 } clip;
       } cache;
       double scale;
+      Evas_Map *map;
       Evas_Coord_Rectangle geometry;
       struct {
 	 unsigned char  r, g, b, a;
       } color;
       Evas_Object      *clipper;
       short             layer;
+      Eina_Bool         usemap : 1;
       Eina_Bool         visible : 1;
       Eina_Bool         have_clipees : 1;
       Eina_Bool         anti_alias : 1;
@@ -437,6 +459,7 @@ struct _Evas_Object
    Eina_Bool                   restack : 1;
    Eina_Bool                   changed : 1;
    Eina_Bool                   is_active : 1;
+   
    Eina_Bool                   render_pre : 1;
    Eina_Bool                   rect_del : 1;
    Eina_Bool                   mouse_in : 1;
@@ -445,7 +468,9 @@ struct _Evas_Object
    Eina_Bool                   focused : 1;
    Eina_Bool                   in_layer : 1;
    Eina_Bool                   no_propagate : 1;
+   
    Eina_Bool                   precise_is_inside : 1;
+   Eina_Bool                   havemap_parent : 1;
 
    unsigned char               delete_me;
 };
@@ -522,6 +547,8 @@ struct _Evas_Object_Func
 
    int (*has_opaque_rect) (Evas_Object *obj);
    int (*get_opaque_rect) (Evas_Object *obj, Evas_Coord *x, Evas_Coord *y, Evas_Coord *w, Evas_Coord *h);
+
+   int (*can_map) (Evas_Object *obj);
 };
 
 struct _Evas_Func
@@ -671,6 +698,11 @@ struct _Evas_Func
 
    void (*image_scale_hint_set)            (void *data, void *image, int hint);
    int  (*image_scale_hint_get)            (void *data, void *image);
+   int  (*font_last_up_to_pos)             (void *data, void *font, const char *text, int x, int y);
+
+   void (*image_map4_draw)                 (void *data, void *context, void *surface, void *image, RGBA_Map_Point *p, int smooth, int level);
+   void *(*image_map_surface_new)          (void *data, int w, int h, int alpha);
+   void *(*image_map_surface_free)         (void *data, void *surface);
 };
 
 struct _Evas_Image_Load_Func
@@ -789,7 +821,8 @@ struct _Evas_Imaging_Font
 
 int evas_async_events_init(void);
 int evas_async_events_shutdown(void);
-
+int evas_async_target_del(const void *target);
+       
 void _evas_walk(Evas *e);
 void _evas_unwalk(Evas *e);
 
@@ -798,6 +831,9 @@ EAPI int _evas_module_engine_inherit(Evas_Func *funcs, char *name);
 void evas_render_invalidate(Evas *e);
 void evas_render_object_recalc(Evas_Object *obj);
 
+Eina_Bool evas_map_inside_get(const Evas_Map *m, Evas_Coord x, Evas_Coord y);
+Eina_Bool evas_map_coords_get(const Evas_Map *m, Evas_Coord x, Evas_Coord y, Evas_Coord *mx, Evas_Coord *my, int grab);
+       
 #define EVAS_API_OVERRIDE(func, api, prefix) \
      (api)->func = prefix##func
 
