@@ -17,6 +17,7 @@
 //#define DFB_DEBUG_IMAGE 1
 //#define DFB_DEBUG_FLAGS 1
 //#define DFB_DEBUG_ACCELERATION 1
+int _evas_engine_directfb_log_dom = -1;
 
 static Evas_Func func = {};
 static Evas_Func parent_func = {};
@@ -69,8 +70,8 @@ _dfb_surface_clear(IDirectFBSurface *surface, int x, int y, int w, int h)
    return;
 
  error:
-   fprintf(stderr, "ERROR: could not clear surface: %s\n",
-	   DirectFBErrorString(r));
+   ERR("DirectFB: could not clear surface: %s",
+	 DirectFBErrorString(r));
 }
 
 static void
@@ -93,7 +94,7 @@ _image_autoset_alpha(DirectFB_Engine_Image_Entry *image)
    r = surface->GetPixelFormat(surface, &fmt);
    if (r != DFB_OK)
      {
-	fprintf(stderr, "ERROR: could not get pixel format: %s\n",
+       ERR("Could not get pixel format: %s",
 		DirectFBErrorString(r));
 	return;
      }
@@ -114,8 +115,8 @@ _dfb_surface_update(IDirectFBSurface *surface, int x, int y, int w, int h)
    cr.y2 = y + h - 1;
    r = surface->Flip(surface, &cr, DSFLIP_NONE);
    if (r != DFB_OK)
-     fprintf(stderr, "ERROR: could not update surface: %s\n",
-	     DirectFBErrorString(r));
+     WRN("Could not update surface: %s",
+	   DirectFBErrorString(r));
 }
 
 static IDirectFBSurface *
@@ -138,8 +139,8 @@ _dfb_surface_from_data(IDirectFB *dfb, int w, int h, void *data)
    r = dfb->CreateSurface(dfb, &desc, &s);
    if (r != DFB_OK)
      {
-	fprintf(stderr, "ERROR: cannot create DirectFB surface: %s\n",
-		DirectFBErrorString(r));
+	ERR("Cannot create DirectFB surface: %s",
+		     DirectFBErrorString(r));
 	return NULL;
      }
 
@@ -165,14 +166,14 @@ _dfb_blit_accel_caps_print(IDirectFBSurface *dst, IDirectFBSurface *src)
    r = dst->GetAccelerationMask(dst, src, &mask);
    if (r != DFB_OK)
      {
-	fprintf(stderr, "ERROR: Could not retrieve acceleration mask: %s\n",
+	ERR("Could not retrieve acceleration mask: %s",
 		DirectFBErrorString(r));
 	return;
      }
 
-   fputs("Acceleration: ", stderr);
+   DBG("Acceleration: ");
 
-#define O(m) if (mask & m) fputs(#m " ", stderr)
+#define O(m) if (mask & m) DBG(#m " ")
    O(DFXL_FILLRECTANGLE);
    O(DFXL_DRAWRECTANGLE);
    O(DFXL_DRAWLINE);
@@ -183,8 +184,7 @@ _dfb_blit_accel_caps_print(IDirectFBSurface *dst, IDirectFBSurface *src)
    O(DFXL_DRAWSTRING);
 #undef O
 
-   if (mask == DFXL_NONE) fputs("<NONE>", stderr);
-   fputc('\n', stderr);
+   if (mask == DFXL_NONE) DBG("<NONE>");
 #endif /* DFB_DEBUG_ACCELERATION */
 }
 
@@ -300,14 +300,14 @@ _dfb_surface_set_color_from_context(IDirectFBSurface *surface, RGBA_Draw_Context
      goto error;
 
 #ifdef DFB_DEBUG_FLAGS
-   printf("DRAW: color=%d %d %d %d, flags=%s\n",
+   DBG("Color=%d %d %d %d, flags=%s",
 	  r, g, b, a, _dfb_draw_flags_str(flags));
 #endif /* DFB_DEBUG_FLAGS */
 
    return 1;
 
  error:
-   fprintf(stderr, "ERROR: could not set color from context: %s\n",
+   ERR("Could not set color from context: %s",
 	   DirectFBErrorString(res));
    return 0;
 }
@@ -354,7 +354,7 @@ _dfb_surface_set_blit_params(DirectFB_Engine_Image_Entry *d, DirectFB_Engine_Ima
      goto error;
 
 #ifdef DFB_DEBUG_FLAGS
-   printf("BLIT: sfunc=%s, dfunc=%s, color=%d %d %d %d\n\tblit=%s\n\tdraw=%s\n",
+   DBG("sfunc=%s, dfunc=%s, color=%d %d %d %d\n\tblit=%s\n\tdraw=%s",
 	  _dfb_blend_func_str(src_func), _dfb_blend_func_str(dst_func),
 	  r, g, b, a,
 	  _dfb_blit_flags_str(blit_flags), _dfb_draw_flags_str(draw_flags));
@@ -363,8 +363,8 @@ _dfb_surface_set_blit_params(DirectFB_Engine_Image_Entry *d, DirectFB_Engine_Ima
    return 1;
 
  error:
-   fprintf(stderr, "ERROR: Could not set blit params: %s\n",
-	   DirectFBErrorString(res));
+   ERR("Could not set blit params: %s",
+	 DirectFBErrorString(res));
    return 0;
 }
 
@@ -386,9 +386,8 @@ _dfb_lock_and_sync_image(IDirectFBSurface *surface, RGBA_Image *image, DFBSurfac
    if (pitch != (sw * 4))
      {
 	/* XXX TODO: support other pixel formats. */
-	fprintf(stderr,
-		"ERROR: IDirectFBSurface pitch(%d) is not supported: "
-		"should be %d.\n",
+       ERR("IDirectFBSurface pitch(%d) is not supported: "
+		"should be %d.",
 		pitch, sw * 4);
 	surface->Unlock(surface);
 	return 0;
@@ -408,6 +407,19 @@ _dfb_surface_for_each_cutout(IDirectFBSurface *surface, RGBA_Draw_Context *dc, _
    int i;
 
    rects = evas_common_draw_context_apply_cutouts(dc);
+   if (!rects)
+     {
+	DFBRegion cr;
+	cr.x1 = 0;
+	cr.y1 = 0;
+	surface->GetSize(surface, &cr.x2, &cr.y2);
+	cr.x2 -= 1;
+	cr.y2 -= 1;
+	surface->SetClip(surface, NULL);
+	cb(surface, dc, &cr, data);
+	return;
+     }
+
    for (i = 0; i < rects->active; ++i)
      {
 	Cutout_Rect *r;
@@ -600,7 +612,7 @@ evas_cache_image_dfb_mem_size_get(Engine_Image_Entry *eie)
    r = deie->surface->GetSize(deie->surface, &w, &h);
    if (r != DFB_OK)
      {
-	fprintf(stderr, "ERROR: Could not get surface size: %s\n",
+	ERR("Could not get surface size: %s",
 		DirectFBErrorString(r));
 	return size;
      }
@@ -616,22 +628,20 @@ evas_cache_image_dfb_debug(const char *context, Engine_Image_Entry* eie)
 {
    DirectFB_Engine_Image_Entry *eim = (DirectFB_Engine_Image_Entry *)eie;
 
-   fprintf(stderr, "*** %s image (%p) ***\n", context, eim);
+   DBG("*** %s image (%p) ***", context, eim);
    if (eim)
      {
-        fprintf(stderr,
-		"* W: %d\n"
+       DBG("* W: %d\n"
 		"* H: %d\n"
 		"* R: %d\n"
 		"* Key: %s\n"
-		"* DFB Surface: %p\n",
+		"* DFB Surface: %p",
 		eie->w, eie->h, eie->references, eie->cache_key, eim->surface);
 
         if (eie->src)
-          fprintf(stderr,
-		  "* Pixels: %p\n", ((RGBA_Image*) eie->src)->image.data);
+          DBG("* Pixels: %p", ((RGBA_Image*) eie->src)->image.data);
      }
-   fputs("*** ***\n", stderr);
+   DBG("*** ***");
 }
 #endif
 
@@ -662,13 +672,10 @@ static void *
 evas_engine_dfb_info(Evas* e __UNUSED__)
 {
    Evas_Engine_Info_DirectFB *info;
-
    info = calloc(1, sizeof(Evas_Engine_Info_DirectFB));
    if (!info)
      return NULL;
-
    info->magic.magic = rand();
-
    return info;
 }
 
@@ -676,7 +683,6 @@ static void
 evas_engine_dfb_info_free(Evas *e __UNUSED__, void *in)
 {
    Evas_Engine_Info_DirectFB *info = in;
-
    free(info);
 }
 
@@ -688,29 +694,28 @@ _is_dfb_data_ok(IDirectFB *idfb, IDirectFBSurface *surface, int w, int h)
 
    if (!idfb)
      {
-	fputs("ERROR: missing IDirectFB\n", stderr);
+	ERR("missing IDirectFB");
 	return EINA_FALSE;
      }
    dfb = idfb;
 
    if (!surface)
      {
-	fputs("ERROR: missing IDirectFBSurface\n", stderr);
+       ERR("missing IDirectFBSurface");
 	return EINA_FALSE;
      }
 
    r = surface->GetSize(surface, &sw, &sh);
    if (r != DFB_OK)
      {
-	fprintf(stderr, "ERROR: could not get surface %p size: %s\n",
-		surface, DirectFBErrorString(r));
+       ERR("Could not get surface %p size: %s",
+	     surface, DirectFBErrorString(r));
 	return EINA_FALSE;
      }
 
    if ((w > sw) || (h > sh))
      {
-	fprintf(stderr,
-		"ERROR: requested size is larger than surface: %dx%d > %dx%d\n",
+       ERR("Requested size is larger than surface: %dx%d > %dx%d",
 		w, h, sw, sh);
 	return EINA_FALSE;
      }
@@ -737,7 +742,7 @@ _evas_common_init(void)
    evas_common_line_init();
    evas_common_font_init();
    evas_common_draw_init();
-   evas_common_tilebuf_init();
+   evas_common_tilebuf_init();  
 }
 
 static int
@@ -752,7 +757,7 @@ evas_engine_dfb_output_reconfigure(Render_Engine *re, int w, int h)
    re->tb = evas_common_tilebuf_new(w, h);
    if (!re->tb)
      {
-	fputs("ERROR: could not allocate tile buffer.\n", stderr);
+	ERR("Could not allocate tile buffer.");
 	goto failed_tilebuf;
      }
    evas_common_tilebuf_set_tile_size(re->tb, TILESIZE, TILESIZE);
@@ -765,7 +770,7 @@ evas_engine_dfb_output_reconfigure(Render_Engine *re, int w, int h)
      evas_cache_engine_image_engine(re->cache, re->spec->surface);
    if (!re->screen_image)
      {
-	fputs("ERROR: RGBA_Image allocation from DFB failed\n", stderr);
+	ERR("RGBA_Image allocation from DFB failed");
 	goto failed_image;
      }
    re->screen_image->flags.engine_surface = 1;
@@ -780,7 +785,7 @@ evas_engine_dfb_output_reconfigure(Render_Engine *re, int w, int h)
    re->tb = NULL;
  failed_tilebuf:
    re->screen_image = NULL;
-   fputs("ERROR: Evas DirectFB reconfigure failed\n", stderr);
+   ERR("Evas DirectFB reconfigure failed");
    return 0;
 }
 
@@ -806,13 +811,13 @@ _dfb_output_setup(int w, int h, const struct Evas_Engine_DirectFB_Spec *spec)
 					    evas_common_image_cache_get());
    if (!re->cache)
      {
-	fputs("ERROR: Evas_Cache_Engine_Image allocation failed!\n", stderr);
+	ERR("Evas_Cache_Engine_Image allocation failed!");
 	goto fatal_after_engine;
      }
 
    if (!evas_engine_dfb_output_reconfigure(re, w, h))
      {
-	fputs("ERROR: Could not reconfigure evas engine.\n", stderr);
+	ERR("Could not reconfigure evas engine.");
 	goto fatal_after_reconfigure;
      }
 
@@ -826,7 +831,7 @@ _dfb_output_setup(int w, int h, const struct Evas_Engine_DirectFB_Spec *spec)
  fatal_after_engine:
    free(re);
  fatal:
-   fputs("FATAL: unable to continue, abort()!\n", stderr);
+   CRIT("DirectFB: unable to continue, abort()!");
    abort();
    return NULL;
 }
@@ -874,7 +879,7 @@ static void
 evas_engine_dfb_output_resize(void *data, int w, int h)
 {
    if (!evas_engine_dfb_output_reconfigure(data, w, h))
-     fputs("ERROR: failed to resize DirectFB evas\n", stderr);
+     ERR("Failed to resize DirectFB evas");
 }
 
 static void
@@ -1018,7 +1023,7 @@ evas_engine_dfb_output_idle_flush(void *data)
    Render_Engine *re = data;
 
    if (re->update_regions_count != 0)
-     fputs("ERROR: update_regions_count not 0 as it should be!\n", stderr);
+     ERR("update_regions_count not 0 as it should be!");
 
    free(re->update_regions);
    re->update_regions_count = 0;
@@ -1087,13 +1092,22 @@ _cb_draw_rectangle(IDirectFBSurface *surface, RGBA_Draw_Context *dc __UNUSED__,
 }
 
 static void
-evas_engine_dfb_rectangle_draw(void *data __UNUSED__, void *context, void *surface, int x, int y, int w, int h)
+evas_engine_dfb_rectangle_draw(void *data, void *context, void *surface, int x, int y, int w, int h)
 {
    IDirectFBSurface *screen = surface;
+   Render_Engine *re = data;
+   RGBA_Draw_Context *dc = context;
    Eina_Rectangle r;
 
    if (!_dfb_surface_set_color_from_context(screen, context))
-     return;
+     {
+	if (dc->render_op != EVAS_RENDER_COPY)
+	  return;
+	if (!re->screen_image->cache_entry.src->flags.alpha)
+	  return;
+	screen->SetColor(screen, 0, 0, 0, 0);
+	screen->SetDrawingFlags(screen, DSDRAW_NOFX);
+     }
 
    EINA_RECTANGLE_SET(&r, x, y, w, h);
    _dfb_surface_for_each_cutout(screen, context, _cb_draw_rectangle, &r);
@@ -1329,7 +1343,7 @@ evas_engine_dfb_image_data_get(void *data __UNUSED__, void *image, int to_write,
 	  break;
 
        error:
-	  fprintf(stderr, "ERROR: could not lock surface %p: %s\n",
+	  ERR("Could not lock surface %p: %s",
 		  s, DirectFBErrorString(r));
 	  *image_data = NULL;
 	  break;
@@ -1614,6 +1628,12 @@ module_open(Evas_Module *em)
    if (!em) return 0;
    /* get whatever engine module we inherit from */
    if (!_evas_module_engine_inherit(&parent_func, "software_generic")) return 0;
+   _evas_engine_directfb_log_dom = eina_log_domain_register("EvasEngineDirectFB",EVAS_DEFAULT_LOG_COLOR);
+   if(_evas_engine_directfb_log_dom < 0)
+     {
+       EINA_LOG_ERR("Impossible to create a log domain for the DirectFb engine.\n");
+       return 0;
+     }
    /* store it for later use */
    func = parent_func;
    /* now to override methods */
@@ -1621,6 +1641,7 @@ module_open(Evas_Module *em)
    ORD(info);
    ORD(info_free);
    ORD(setup);
+   ORD(canvas_alpha_get);
    ORD(output_free);
    ORD(output_resize);
    ORD(output_tile_size_set);
@@ -1658,6 +1679,11 @@ module_open(Evas_Module *em)
    ORD(gradient_draw);
    ORD(image_scale_hint_set);
    ORD(image_scale_hint_get);
+
+//   ORD(image_map4_draw);
+//   ORD(image_map_surface_new);
+//   ORD(image_map_surface_free);
+
    /* now advertise out own api */
    em->functions = (void *)(&func);
    return 1;
@@ -1666,6 +1692,7 @@ module_open(Evas_Module *em)
 static void
 module_close(Evas_Module *em)
 {
+   eina_log_domain_unregister(_evas_engine_directfb_log_dom);
 }
 
 static Evas_Module_Api evas_modapi =
