@@ -8,9 +8,8 @@
  **
  *****
  */
-
 static int cpunum = 0;
-
+static int _evas_soft_gen_log_dom = -1;
 static void *
 eng_context_new(void *data __UNUSED__)
 {
@@ -777,6 +776,35 @@ eng_image_draw(void *data __UNUSED__, void *context, void *surface, void *image,
      }
 }
 
+static void
+eng_image_map4_draw(void *data __UNUSED__, void *context, void *surface, void *image, RGBA_Map_Point *p, int smooth, int level)
+{
+   RGBA_Image *im;
+
+   if (!image) return;
+   im = image;
+   evas_common_map4_rgba(im, surface, context, p, smooth, level);
+   evas_common_cpu_end_opt();
+}
+
+static void *
+eng_image_map_surface_new(void *data __UNUSED__, int w, int h, int alpha)
+{
+   void *surface;
+   DATA32 *pixels;
+   surface = evas_cache_image_copied_data(evas_common_image_cache_get(), 
+                                          w, h, NULL, alpha, 
+                                          EVAS_COLORSPACE_ARGB8888);
+   pixels = evas_cache_image_pixels(surface);
+   return surface;
+}
+
+static void
+eng_image_map_surface_free(void *data __UNUSED__, void *surface)
+{
+   evas_cache_image_drop(surface);
+}
+
 static void
 eng_image_scale_hint_set(void *data __UNUSED__, void *image, int hint)
 {
@@ -917,6 +945,12 @@ eng_font_char_at_coords_get(void *data __UNUSED__, void *font, const char *text,
    return evas_common_font_query_text_at_pos(font, text, x, y, cx, cy, cw, ch);
 }
 
+static int
+eng_font_last_up_to_pos(void *data __UNUSED__, void *font, const char *text, int x, int y)
+{
+   return evas_common_font_query_last_up_to_pos(font, text, x, y);
+}
+
 static void
 eng_font_draw(void *data __UNUSED__, void *context, void *surface, void *font, int x, int y, int w __UNUSED__, int h __UNUSED__, int ow __UNUSED__, int oh __UNUSED__, const char *text)
 {
@@ -1115,7 +1149,13 @@ static Evas_Func func =
      eng_font_hinting_set,
      eng_font_hinting_can_hint,
      eng_image_scale_hint_set,
-     eng_image_scale_hint_get
+     eng_image_scale_hint_get,
+     /* more font draw functions */
+     eng_font_last_up_to_pos,
+     /* FUTURE software generic calls go here (done) */
+     eng_image_map4_draw,
+     eng_image_map_surface_new,
+     eng_image_map_surface_free
      /* FUTURE software generic calls go here */
 };
 
@@ -1131,14 +1171,21 @@ static int
 module_open(Evas_Module *em)
 {
    if (!em) return 0;
+   _evas_soft_gen_log_dom = eina_log_domain_register("EvasSoftGeneric", EVAS_DEFAULT_LOG_COLOR);
+   if(_evas_soft_gen_log_dom<0)
+     {
+       EINA_LOG_ERR("Evas SoftGen : Impossible to create a log domain for the software generic engine.\n");
+       return 0;
+     }
    em->functions = (void *)(&func);
-   cpunum = evas_common_cpu_count();
+   cpunum = eina_cpu_count();
    return 1;
 }
 
 static void
 module_close(Evas_Module *em)
 {
+  eina_log_domain_unregister(_evas_soft_gen_log_dom);
 }
 
 static Evas_Module_Api evas_modapi =
