@@ -15,6 +15,8 @@
 # include "evas_xcb_color.h"
 #endif
 
+int _evas_engine_soft_x11_log_dom = -1;
+int test ;
 /* function tables - filled in later (func and parent func) */
 static Evas_Func func, pfunc;
 
@@ -320,7 +322,6 @@ static void *
 eng_info(Evas *e __UNUSED__)
 {
    Evas_Engine_Info_Software_X11 *info;
-
    info = calloc(1, sizeof(Evas_Engine_Info_Software_X11));
    if (!info) return NULL;
    info->magic.magic = rand();
@@ -337,7 +338,6 @@ static void
 eng_info_free(Evas *e __UNUSED__, void *info)
 {
    Evas_Engine_Info_Software_X11 *in;
-
    in = (Evas_Engine_Info_Software_X11 *)info;
    free(in);
 }
@@ -345,8 +345,8 @@ eng_info_free(Evas *e __UNUSED__, void *info)
 static int
 eng_setup(Evas *e, void *in)
 {
-   Render_Engine                 *re;
    Evas_Engine_Info_Software_X11 *info;
+   Render_Engine *re = NULL;
 
    info = (Evas_Engine_Info_Software_X11 *)in;
    if (!e->engine.data.output)
@@ -628,7 +628,7 @@ eng_output_idle_flush(void *data)
 }
 
 static Eina_Bool
-eng_canvas_alpha_get(void *data, void *context)
+eng_canvas_alpha_get(void *data, void *context __UNUSED__)
 {
    Render_Engine *re;
 
@@ -643,6 +643,12 @@ module_open(Evas_Module *em)
    if (!em) return 0;
    /* get whatever engine module we inherit from */
    if (!_evas_module_engine_inherit(&pfunc, "software_generic")) return 0;
+   _evas_engine_soft_x11_log_dom = eina_log_domain_register("EvasSoftX11", EVAS_DEFAULT_LOG_COLOR);
+   if(_evas_engine_soft_x11_log_dom < 0)
+     {
+       EINA_LOG_ERR("Impossible to create a log domain for the SoftX11 engine.\n");
+       return 0;
+     }
    /* store it for later use */
    func = pfunc;
    /* now to override methods */
@@ -667,8 +673,9 @@ module_open(Evas_Module *em)
 }
 
 static void
-module_close(Evas_Module *em)
+module_close(Evas_Module *em __UNUSED__)
 {
+  eina_log_domain_unregister(_evas_engine_soft_x11_log_dom);
 }
 
 static Evas_Module_Api evas_modapi =
