@@ -32,17 +32,16 @@
 #define PNG_BYTES_TO_CHECK 4
 
 
-int evas_image_load_file_head_png(Image_Entry *ie, const char *file, const char *key);
-int evas_image_load_file_data_png(Image_Entry *ie, const char *file, const char *key);
+static int evas_image_load_file_head_png(Image_Entry *ie, const char *file, const char *key);
+static int evas_image_load_file_data_png(Image_Entry *ie, const char *file, const char *key);
 
-Evas_Image_Load_Func evas_image_load_png_func =
+static Evas_Image_Load_Func evas_image_load_png_func =
 {
   evas_image_load_file_head_png,
   evas_image_load_file_data_png
 };
 
-
-int
+static int
 evas_image_load_file_head_png(Image_Entry *ie, const char *file, const char *key)
 {
    png_uint_32 w32, h32;
@@ -86,7 +85,8 @@ evas_image_load_file_head_png(Image_Entry *ie, const char *file, const char *key
    png_get_IHDR(png_ptr, info_ptr, (png_uint_32 *) (&w32),
 		(png_uint_32 *) (&h32), &bit_depth, &color_type,
 		&interlace_type, NULL, NULL);
-   if ((w32 < 1) || (h32 < 1) || (w32 > 8192) || (h32 > 8192))
+   if ((w32 < 1) || (h32 < 1) || (w32 > IMG_MAX_SIZE) || (h32 > IMG_MAX_SIZE) ||
+       IMG_TOO_BIG(w32, h32))
      {
 	png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
 	goto close_file;
@@ -108,7 +108,7 @@ evas_image_load_file_head_png(Image_Entry *ie, const char *file, const char *key
    key = 0;
 }
 
-int
+static int
 evas_image_load_file_data_png(Image_Entry *ie, const char *file, const char *key)
 {
    unsigned char *surface;
@@ -217,7 +217,7 @@ evas_image_load_file_data_png(Image_Entry *ie, const char *file, const char *key
    key = 0;
 }
 
-EAPI int
+static int
 module_open(Evas_Module *em)
 {
    if (!em) return 0;
@@ -225,16 +225,24 @@ module_open(Evas_Module *em)
    return 1;
 }
 
-EAPI void
-module_close(void)
+static void
+module_close(Evas_Module *em)
 {
-
 }
 
-EAPI Evas_Module_Api evas_modapi =
+static Evas_Module_Api evas_modapi =
 {
    EVAS_MODULE_API_VERSION,
-     EVAS_MODULE_TYPE_IMAGE_LOADER,
-     "png",
-     "none"
+   "png",
+   "none",
+   {
+     module_open,
+     module_close
+   }
 };
+
+EVAS_MODULE_DEFINE(EVAS_MODULE_TYPE_IMAGE_LOADER, image_loader, png);
+
+#ifndef EVAS_STATIC_BUILD_PNG
+EVAS_EINA_MODULE_DEFINE(image_loader, png);
+#endif
