@@ -10,16 +10,15 @@
 #include "evas_common.h"
 #include "evas_private.h"
 
-int evas_image_load_file_head_xpm(Image_Entry *ie, const char *file, const char *key);
-int evas_image_load_file_data_xpm(Image_Entry *ie, const char *file, const char *key);
+static int evas_image_load_file_head_xpm(Image_Entry *ie, const char *file, const char *key);
+static int evas_image_load_file_data_xpm(Image_Entry *ie, const char *file, const char *key);
 
-Evas_Image_Load_Func evas_image_load_xpm_func =
+static Evas_Image_Load_Func evas_image_load_xpm_func =
 {
   evas_image_load_file_head_xpm,
   evas_image_load_file_data_xpm
 };
 
-
 static FILE *rgb_txt = NULL;
 
 static void
@@ -203,8 +202,7 @@ evas_image_load_file_xpm(Image_Entry *ie, const char *file, const char *key __UN
                        /* Header */
                        if (sscanf(line, "%i %i %i %i", &w, &h, &ncolors, &cpp) != 4)
 			 {
-                            fprintf(stderr,
-                                    "XPM ERROR: XPM file malformed header\n");
+			    ERR("XPM ERROR: XPM file malformed header");
                             free(line);
                             fclose(f);
                             xpm_parse_done();
@@ -212,8 +210,7 @@ evas_image_load_file_xpm(Image_Entry *ie, const char *file, const char *key __UN
 			 }
                        if ((ncolors > 32766) || (ncolors < 1))
                          {
-                            fprintf(stderr,
-                                    "XPM ERROR: XPM files with colors > 32766 or < 1 not supported\n");
+                            ERR("XPM ERROR: XPM files with colors > 32766 or < 1 not supported");
                             free(line);
                             fclose(f);
                             xpm_parse_done();
@@ -221,26 +218,31 @@ evas_image_load_file_xpm(Image_Entry *ie, const char *file, const char *key __UN
                          }
                        if ((cpp > 5) || (cpp < 1))
                          {
-                            fprintf(stderr,
-                                    "XPM ERROR: XPM files with characters per pixel > 5 or < 1not supported\n");
+			    ERR("XPM ERROR: XPM files with characters per pixel > 5 or < 1not supported");
                             free(line);
                             fclose(f);
                             xpm_parse_done();
                             return 0;
                          }
-                       if ((w > 8192) || (w < 1))
+                       if ((w > IMG_MAX_SIZE) || (w < 1))
                          {
-                            fprintf(stderr,
-                                    "XPM ERROR: Image width > 8192 or < 1 pixels for file\n");
+			    ERR("XPM ERROR: Image width > IMG_MAX_SIZE or < 1 pixels for file");
                             free(line);
                             fclose(f);
                             xpm_parse_done();
                             return 0;
                          }
-                       if ((h > 8192) || (h < 1))
+                       if ((h > IMG_MAX_SIZE) || (h < 1))
                          {
-                            fprintf(stderr,
-                                    "XPM ERROR: Image height > 8192 or < 1 pixels for file\n");
+			    ERR("XPM ERROR: Image height > IMG_MAX_SIZE or < 1 pixels for file");
+                            free(line);
+                            fclose(f);
+                            xpm_parse_done();
+                            return 0;
+                         }
+                       if (IMG_TOO_BIG(w, h))
+                         {
+                            ERR("XPM ERROR: Image just too big to ever allocate");
                             free(line);
                             fclose(f);
                             xpm_parse_done();
@@ -617,22 +619,19 @@ evas_image_load_file_xpm(Image_Entry *ie, const char *file, const char *key __UN
    return 1;
 }
 
-
-int
+static int
 evas_image_load_file_head_xpm(Image_Entry *ie, const char *file, const char *key)
 {
   return evas_image_load_file_xpm(ie, file, key, 0);
 }
 
-int
+static int
 evas_image_load_file_data_xpm(Image_Entry *ie, const char *file, const char *key)
 {
   return evas_image_load_file_xpm(ie, file, key, 1);
 }
 
-
-
-EAPI int
+static int
 module_open(Evas_Module *em)
 {
    if (!em) return 0;
@@ -640,16 +639,24 @@ module_open(Evas_Module *em)
    return 1;
 }
 
-EAPI void
-module_close(void)
+static void
+module_close(Evas_Module *em)
 {
-
 }
 
-EAPI Evas_Module_Api evas_modapi =
+static Evas_Module_Api evas_modapi =
 {
    EVAS_MODULE_API_VERSION,
-     EVAS_MODULE_TYPE_IMAGE_LOADER,
-     "xpm",
-     "none"
+   "xpm",
+   "none",
+   {
+     module_open,
+     module_close
+   }
 };
+
+EVAS_MODULE_DEFINE(EVAS_MODULE_TYPE_IMAGE_LOADER, image_loader, xpm);
+
+#ifndef EVAS_STATIC_BUILD_XPM
+EVAS_EINA_MODULE_DEFINE(image_loader, xpm);
+#endif
